==> visualpython-0.2.6.tar.gz: visualpython-0.2.6/visualpython/src/numpy/common/NumpyPageRender/parent/privateMethod/index.js <==
define ([
      './_renderParamArrayEditorTitle'
    , './_resetArrayEditor'
    , './_renderEditorModalOpenBtn'
    , './_renderParamTabBlock'
    , './_renderParamOneArrayEditor'
    , './_renderParamTwoArrayEditor'
    , './_renderParamThreeArrayEditor'
    , './_renderIndexingEditor'
    , './_renderParamOneArrayIndexValueEditor'
    , './_renderParamInputArrayEditor'
    , './_renderCallVarBlock'
    , './_renderReturnVarBlock'
    , './_renderParamVarBlock'
    , './_renderDtypeBlock'
    , './_renderInputIndexValueBlock'
    , './_renderSelectIndexValueBlock'
    , './_renderSelectAxisBlock'

    , './_renderPostfixCode'
    , './_renderPrefixCode'
    , './_renderAdditionalOptionContainer'
    , './_renderRequiredInputOutputContainer'
], function(
    _renderParamArrayEditorTitle
    , _resetArrayEditor
    , _renderEditorModalOpenBtn
    , _renderParamTabBlock
    , _renderParamOneArrayEditor
    , _renderParamTwoArrayEditor
    , _renderParamThreeArrayEditor
    , _renderIndexingEditor
    , _renderParamOneArrayIndexValueEditor
    , _renderParamInputArrayEditor
    , _renderCallVarBlock
    , _renderReturnVarBlock
    , _renderParamVarBlock
    , _renderDtypeBlock
    , _renderInputIndexValueBlock
    , _renderSelectIndexValueBlock
    , _renderSelectAxisBlock

    , _renderPostfixCode
    , _renderPrefixCode
    , _renderAdditionalOptionContainer
    , _renderRequiredInputOutputContainer
){
    return {
        _renderParamArrayEditorTitle
        , _resetArrayEditor
        , _renderEditorModalOpenBtn
        , _renderParamTabBlock
        , _renderParamOneArrayEditor
        , _renderParamTwoArrayEditor
        , _renderParamThreeArrayEditor
        , _renderIndexingEditor
        , _renderParamOneArrayIndexValueEditor
        , _renderParamInputArrayEditor
        , _renderCallVarBlock
        , _renderReturnVarBlock
        , _renderParamVarBlock
        , _renderDtypeBlock
        , _renderInputIndexValueBlock
        , _renderSelectIndexValueBlock
        , _renderSelectAxisBlock

        , _renderPostfixCode
        , _renderPrefixCode
        , _renderAdditionalOptionContainer
        , _renderRequiredInputOutputContainer
    }
});

==> visualpython-0.2.8.tar.gz: visualpython-0.2.8/visualpython/src/numpy/common/NumpyPageRender/parent/privateMethod/index.js <==
define ([
      './_renderParamArrayEditorTitle'
    , './_resetArrayEditor'
    , './_renderEditorModalOpenBtn'
    , './_renderParamTabBlock'
    , './_renderParamOneArrayEditor'
    , './_renderParamTwoArrayEditor'
    , './_renderParamThreeArrayEditor'
    // , './_renderIndexingEditor'
    , './_renderParamOneArrayIndexValueEditor'
    , './_renderParamInputArrayEditor'
    , './_renderCallVarBlock'
    , './_renderReturnVarBlock'
    , './_renderParamVarBlock'
    , './_renderDtypeBlock'
    , './_renderInputIndexValueBlock'
    , './_renderSelectIndexValueBlock'
    , './_renderSelectAxisBlock'

    , './_renderPostfixCode'
    , './_renderPrefixCode'
    , './_renderAdditionalOptionContainer'
    , './_renderRequiredInputOutputContainer'
    , './_renderUserOption'
], function(
    _renderParamArrayEditorTitle
    , _resetArrayEditor
    , _renderEditorModalOpenBtn
    , _renderParamTabBlock
    , _renderParamOneArrayEditor
    , _renderParamTwoArrayEditor
    , _renderParamThreeArrayEditor
    // , _renderIndexingEditor
    , _renderParamOneArrayIndexValueEditor
    , _renderParamInputArrayEditor
    , _renderCallVarBlock
    , _renderReturnVarBlock
    , _renderParamVarBlock
    , _renderDtypeBlock
    , _renderInputIndexValueBlock
    , _renderSelectIndexValueBlock
    , _renderSelectAxisBlock

    , _renderPostfixCode
    , _renderPrefixCode
    , _renderAdditionalOptionContainer
    , _renderRequiredInputOutputContainer
    , _renderUserOption
){
    return {
        _renderParamArrayEditorTitle
        , _resetArrayEditor
        , _renderEditorModalOpenBtn
        , _renderParamTabBlock
        , _renderParamOneArrayEditor
        , _renderParamTwoArrayEditor
        , _renderParamThreeArrayEditor
        // , _renderIndexingEditor
        , _renderParamOneArrayIndexValueEditor
        , _renderParamInputArrayEditor
        , _renderCallVarBlock
        , _renderReturnVarBlock
        , _renderParamVarBlock
        , _renderDtypeBlock
        , _renderInputIndexValueBlock
        , _renderSelectIndexValueBlock
        , _renderSelectAxisBlock

        , _renderPostfixCode
        , _renderPrefixCode
        , _renderAdditionalOptionContainer
        , _renderRequiredInputOutputContainer
        , _renderUserOption
    }
});
